#
# spec file for package maven-compiler-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
%global base_name maven-compiler-plugin
Version:        3.11.0
Release:        2.6
Summary:        Maven Compiler Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-compiler-plugin
Source0:        https://archive.apache.org/dist/maven/plugins/%{base_name}-%{version}-source-release.zip
Source1:        %{base_name}-build.xml
Patch0:         %{base_name}-bootstrap-resources.patch
BuildRequires:  javapackages-local
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  maven-resolver-api
BuildRequires:  maven-resolver-util
BuildRequires:  maven-shared-incremental
BuildRequires:  maven-shared-utils
BuildRequires:  objectweb-asm
BuildRequires:  plexus-compiler >= 2.13
BuildRequires:  plexus-languages
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
BuildRequires:  ant
%else
Name:           %{base_name}
BuildRequires:  fdupes
BuildRequires:  xmvn
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
Obsoletes:      %{base_name}-bootstrap
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
%endif

%description
The Compiler Plugin is used to compile the sources of your project.

%if %{without bootstrap}
%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
%if %{with bootstrap}
cp %{SOURCE1} build.xml
%patch -P 0 -p1
%endif

%pom_remove_dep :::test

# There is nothing to index and this creates a cycle
%pom_remove_plugin org.eclipse.sisu:sisu-maven-plugin

%pom_xpath_remove pom:project/pom:parent/pom:relativePath

%build
%if %{with bootstrap}
mkdir -p lib
build-jar-repository -s lib \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-plugin-api \
    maven-plugin-tools/maven-plugin-annotations \
    maven-resolver/maven-resolver-api \
    maven-resolver/maven-resolver-util \
    maven-shared-incremental/maven-shared-incremental \
    maven-shared-utils/maven-shared-utils \
    objectweb-asm/asm-all \
    plexus-compiler/plexus-compiler-api \
    plexus-compiler/plexus-compiler-javac \
    plexus-compiler/plexus-compiler-manager \
    plexus-languages/plexus-java
%{ant} -Dtest.skip=true jar
%else
xmvn --batch-mode --offline \
    -Dmaven.test.skip=true \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    package org.apache.maven.plugins:maven-javadoc-plugin:aggregate
%endif

%{mvn_artifact} pom.xml target/%{base_name}-%{version}.jar

%install
%mvn_install
%if %{without bootstrap}
%fdupes -s %{buildroot}%{_javadocdir}
%endif

%files -f .mfiles
%license LICENSE NOTICE

%if %{without bootstrap}
%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE
%endif

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 20 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream release 3.11.0
  * New features and improvements
    + MCOMPILER-494: Add a useModulePath switch to the testCompile
    mojo
    + MCOMPILER-395: Allow dependency exclusions for
    'annotationProcessorPaths'
    + MCOMPILER-522: Use maven-resolver to resolve
    'annotationProcessorPaths' dependencies
    + MCOMPILER-516: upgrade plexus-compiler to improve compiling
    message
    + MCOMPILER-501: compileSourceRoots parameter should be writable
    + MCOMPILER-457: Change showWarnings to true by default
    + MCOMPILER-457: Warn about warn-config conflicting values
    + MCOMPILER-505: Update default source/target from 1.7 to 1.8
    + MCOMPILER-499: display recompilation causes
    + MCOMPILER-500: add some parameter to pattern from stale source
    calculation
    + MCOMPILER-488: dedicated option for implicit javac flag
  * Bug Fixes
    + MCOMPILER-525: Incorrect detection of dependency change
    + MCOMPILER-523: Test with Maven 3.9.0 and fix the failing IT
    + MCOMPILER-503: Resolve all annotation processor dependencies
    together
    + MCOMPILER-512: Defining maven.compiler.release as empty string
    ends with NumberFormatException in testCompileMojo
    + MCOMPILER-495: Fixes missing dirs in
    createMissingPackageInfoClasses
    + MCOMPILER-347: Set Xcludes in config passed to actual compiler
- Modified patch:
  * maven-compiler-plugin-bootstrap-resources.patch
    + regenerate in cycle by itself
* Sat Mar 12 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream release 3.10.1
  * Removed
    + [MCOMPILER-484] - Remove deprecated mojos
  * New features and improvements:
    + [MCOMPILER-426] - add flag to enable-preview java compiler
    feature
    + [MCOMPILER-205] - Add a boolean to generate missing
    package-info classes by default
    + [MCOMPILER-474] - Also check jar files when determining if
    dependencies changed
  * Bug Fixes:
    + [MCOMPILER-346] - workaround to jdk bug: assertion error from
    javaxcompiler javax.tools API
    + [MCOMPILER-485] - Fixes internal string format in generated
    package-info.class
    + [MCOMPILER-225] - javac.sh/javac.bat added to archive
    + [MCOMPILER-481] - compiler plugin should include static module
    for compilation
    + [MCOMPILER-470] -parameters doesn't work with --release
    + [MCOMPILER-460] - Compiler doesn't show detailed information
    with the Maven Toolchains
  * Other changes:
    + [MCOMPILER-341] Compile module descriptors with
    TestCompilerMojo
    + [MCOMPILER-349] changed dependency detection
    + [MCOMPILER-360] nullpointer exception
    + [MCOMPILER-306] Fix compilerArgs example usage
    + [MCOMPILER-349] cleanups
    + [MCOMPILER-359] Fix for NPE
    + [MCOMPILER-475] Shared GitHub Actions
- Removed patches:
  * 0001-plexus-languages-1.0.patch
  * 0002-MCOMPILER-359-Fix-for-NPE.patch
    + not needed with this version
* Thu Mar 10 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * 00-plexus-languages-1.0.patch -> 0001-plexus-languages-1.0.patch
    + Sync with patch used by Fedora
- Added patch:
  * 0002-MCOMPILER-359-Fix-for-NPE.patch
    + Fix null pointer exception in tests compilation
* Fri Nov 29 2019 Fridrich Strba <fstrba@suse.com>
- Remove all dependencies with scope test, since we are disabling
  tests
* Mon Nov 25 2019 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.8.1
- Modified patch:
  * maven-compiler-plugin-bootstrap-resources.patch
    + Regenerate from the non-bootstrap build
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 00-plexus-languages-1.0.patch
    + fix build against plexus-java >= 1.0
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Wed Apr  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-compiler-plugin 3.8.0
- Package as a multibuild package in order to allow bootstapping
- Generate and customize ant build.xml file for the bootstrap
  version
- Added patch:
  * maven-compiler-plugin-bootstrap-resources.patch
    + For the bootstrap version, add the pre-generated resources
    that need maven-plugin-plugin
